{{title}}

This 'scribble' application illustrates with a simple 'TODO' example how to use the library flux-view to create reactive UI. We tried to reproduce as much as possible the example of Vue.

The code source of this file is located {{src_folder}} on your computer: do not hesitate to update it and refresh this page.

You can check if other youwol pipelines already exists to create front-end applications (search for yw_pipeline in pipy)

Double click on an item to edit.